/**************************************************************************\
 * 
 *  FILE: Model.h
 *
 *  This source file is part of DIME.
 *  Copyright (C) 1998-1999 by Systems In Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License, version 2, as
 *  published by the Free Software Foundation.  DO NOT MISTAKE THIS LICENSE
 *  FOR THE GNU LGPL LICENSE.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License (the accompanying file named COPYING) for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 **************************************************************************
 *
 *  If you need DIME for commercial purposes, you can contact Systems In
 *  Motion about acquiring a commercial license.
 *
 *  Systems In Motion                                   http://www.sim.no/
 *  Prof. Brochs gate 6                                       sales@sim.no
 *  N-7030 Trondheim                                   Voice: +47 73540378
 *  NORWAY                                               Fax: +47 73943861
 *
\**************************************************************************/

#ifndef DIME_MODEL_H
#define DIME_MODEL_H

#include <dime/Basic.h>
#include <dime/util/Array.h>
#include <dime/util/Linear.h>
#include <dime/Base.h>
#include <dime/Layer.h>
#include <stdlib.h>

class dimeInput;
class dimeOutput;
class dimeDict;
class dimeMemHandler;
class dimeSection;
class dimeEntitiesSection;
class dimeBlocksSection;
class dimeBlock;
class dimeEntity;

class dimeModel
{
public:
  dimeModel();
  ~dimeModel();
  
  dimeModel *copy() const;

  bool init();
  bool read(dimeInput * const in);
  bool write(dimeOutput * const out);

  int countRecords() const;

  bool traverseEntities(dimeCallback callback, 
			void *userdata = NULL,
			bool traverseBlocksSection = false,
			bool explodeInserts = true,
			bool traversePolylineVertices = false);
  
  const char *addReference(const char * const name, void *id);
  void *findReference(const char * const name) const;
  const char *findRefStringPtr(const char * const name) const;
  void removeReference(const char * const name);
  class dimeMemHandler *getMemHandler();
  
  int getNumLayers() const;
  const class dimeLayer *getLayer(const int idx) const;
  const class dimeLayer *getLayer(const char * const layername) const;
  const class dimeLayer *addLayer(const char * const layername, 
			   const int16 colnum = -1,
			   const int16 flags = 0); 
  
  const char * getDxfVersion() const;
  
  static const char *getVersionString();
  static void getVersion(int &major, int &minor);
  const char *addBlock(const char * const blockname, dimeBlock * const block);
  class dimeBlock *findBlock(const char * const blockname);

  class dimeSection *findSection(const char * const sectionname);
  const class dimeSection *findSection(const char * const sectionname) const;

  int getNumSections() const;
  class dimeSection *getSection(const int idx);
  void insertSection(dimeSection * const section, const int idx = -1);
  void removeSection(const int idx);

private:
  class dimeDict *refDict;
  class dimeDict *layerDict;
  class dimeMemHandler *memoryHandler;
  dimeArray <class dimeSection*> sections;
  dimeArray <class dimeLayer*> layers;

}; // class dimeModel

#endif // ! DIME_MODEL_H

/******************************************************************** EOF */
