/**************************************************************************\
 * 
 *  FILE: Box.h
 *
 *  This source file is part of DIME.
 *  Copyright (C) 1998-1999 by Systems In Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License, version 2, as
 *  published by the Free Software Foundation.  DO NOT MISTAKE THIS LICENSE
 *  FOR THE GNU LGPL LICENSE.
 *
 *  This library is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License (the accompanying file named COPYING) for more
 *  details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 **************************************************************************
 *
 *  If you need DIME for commercial purposes, you can contact Systems In
 *  Motion about acquiring a commercial license.
 *
 *  Systems In Motion                                   http://www.sim.no/
 *  Prof. Brochs gate 6                                       sales@sim.no
 *  N-7030 Trondheim                                   Voice: +47 73540378
 *  NORWAY                                               Fax: +47 73943861
 *
\**************************************************************************/

#ifndef DIME_BOX_H
#define DIME_BOX_H

#include <dime/Basic.h>
#include <dime/util/Linear.h>

class dimeBox
{
public:
  dimeVec3f min, max;
public:
  dimeBox();
  dimeBox(const float x0, const float y0, const float z0, 
	 const float x1, const float y1, const float z1);
  
  void set(const float x0, const float y0, const float z0, 
	   const float x1, const float y1, const float z1);

  void get(float &x0, float &y0, float &z0,
	   float &x1, float &y1, float &z1) const;

  bool operator & (const dimeBox &box) const;
  
  bool pointInside(const dimeVec3f &pt) const;

  dimeVec3f center() const;
  
  void makeEmpty();
  void grow(const dimeVec3f &pt);
  float size() const;
  bool hasExtent() const;
}; // class dimeBox

inline bool 
dimeBox::pointInside(const dimeVec3f &pt) const 
{
  return ! (pt[0] < this->min[0] || pt[0] >= this->max[0] || 
	    pt[1] < this->min[1] || pt[1] >= this->max[1] ||
	    pt[2] < this->min[2] || pt[2] >= this->max[2]);
}

inline dimeVec3f 
dimeBox::center() const 
{
  return dimeVec3f((min[0]+max[0])*0.5f, 
		   (min[1]+max[1])*0.5f,
		   (min[2]+max[2])*0.5f);
}

#endif // ! DIME_BOX_H

/******************************************************************** EOF */
